@@ -26,6 +26,15 @@
 #include <stddef.h> /* for offsetof */
 #include <string.h>
 
+#ifdef HAVE_PROJ_H
+/* Work around broken check in proj.h:
+ * https://github.com/OSGeo/PROJ/issues/1523
+ */
+# ifndef PROJ_H
+#  include <proj.h>
+# endif
+#endif
+#define ACCEPT_USE_OF_DEPRECATED_PROJ_API_H 1
 #include <proj_api.h>
 
 #include "cavern.h"
@@ -41,7 +50,8 @@
 #include "readval.h"
 #include "str.h"
 
-/*** Extracted from proj.4 projects (yuck, but grass also does this): */
+#ifndef HAVE_PROJ_H
+/*** Extracted from PROJ 4.x projects.h (yuck, but grass also does this): */
 struct DERIVS {
     double x_l, x_p; /* derivatives of x for lambda-phi */
     double y_l, y_p; /* derivatives of y for lambda-phi */
@@ -59,6 +69,7 @@ struct FACTORS {
 
 int pj_factors(projLP, projPJ *, double, struct FACTORS *);
 /***/
+#endif
 
 static projPJ proj_wgs84;
 
@@ -1706,11 +1717,19 @@ cmd_declination(void)
 	/* Invalidate cached declination. */
 	pcs->declination = HUGE_REAL;
 	{
+#ifdef HAVE_PROJ_H
+	    PJ_COORD lp;
+	    lp.lp.lam = x;
+	    lp.lp.phi = y;
+	    PJ_FACTORS factors = proj_factors(proj_out, lp);
+	    pcs->convergence = factors.meridian_convergence;
+#else
 	    projLP lp = { x, y };
 	    struct FACTORS factors;
 	    memset(&factors, 0, sizeof(factors));
 	    pj_factors(lp, proj_out, 0.0, &factors);
 	    pcs->convergence = factors.conv;
+#endif
 	}
     } else {
 	/* *declination D UNITS */
