@@ -1,6 +1,17 @@
 /* img.h
- * Header file for routines to read and write Survex ".3d" image files
- * Copyright (C) Olly Betts 1993,1994,1997,2001,2002,2003,2004,2005,2006,2010,2011,2012,2013,2014,2016
+ * Header file for routines to read and write processed survey data files
+ *
+ * These routines support reading processed survey data in a variety of formats
+ * - currently:
+ *
+ * - Survex ".3d" image files
+ * - Survex ".pos" files
+ * - Compass Plot files (".plt" and ".plf")
+ * - CMAP XYZ files (".sht", ".adj", ".una", ".xyz")
+ *
+ * Writing Survex ".3d" image files is supported.
+ *
+ * Copyright (C) Olly Betts 1993,1994,1997,2001,2002,2003,2004,2005,2006,2010,2011,2012,2013,2014,2016,2018
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +61,7 @@ extern "C" {
 # define img_LABEL  3
 # define img_XSECT  4
 # define img_XSECT_END 5
-/* Loop closure information for the *preceeding* traverse (img_MOVE + one or
+/* Loop closure information for the *preceding* traverse (img_MOVE + one or
  * more img_LINEs). */
 # define img_ERROR_INFO 6
 
@@ -133,7 +144,12 @@ typedef struct {
    double length;
    double E, H, V;
 
-   /* The filename actually opened (e.g. may have ".3d" added): */
+   /* The filename actually opened (e.g. may have ".3d" added).
+    *
+    * This is only set if img opened the filename - if an existing stream
+    * is used (via img_read_stream() or similar) then this member will be
+    * NULL.
+    */
    char * filename_opened;
 
    /* Non-zero if reading an extended elevation: */
@@ -145,6 +161,7 @@ typedef struct {
 
    /* All other members are for internal use only: */
    FILE *fh;          /* file handle of image file */
+   int (*close_func)(FILE*);
    char *label_buf;
    size_t buf_len;
    size_t label_len;
@@ -187,38 +204,95 @@ extern unsigned int img_output_version;
 /* Maximum supported value for img_output_version: */
 #define IMG_VERSION_MAX 8
 
-/* Open a .3d file for reading
+/* Open a processed survey data file for reading
+ *
  * fnm is the filename
+ *
  * Returns pointer to an img struct or NULL
  */
 #define img_open(F) img_open_survey((F), NULL)
 
-/* Open a .3d file for reading
+/* Open a processed survey data file for reading
+ *
  * fnm is the filename
- * Returns pointer to an img struct or NULL
+ *
  * survey points to a survey name to restrict reading to (or NULL for all
  * survey data in the file)
+ *
+ * Returns pointer to an img struct or NULL
  */
 img *img_open_survey(const char *fnm, const char *survey);
 
-/* Open a .3d file for output
- * fnm is the filename
- * title is the title
- * flags contains a bitwise-or of any file-wide flags - currently only one
- * is available: img_FFLAG_EXTENDED.  (The third parameter used to be
- * 'fBinary', but has been ignored for many years, so the parameter has
- * been repurposed for flags - for this reason, img.c deliberately ignores bit
- * 1 being set, but callers should be written/updated not to set it).
+/* Read processed survey data from an existing stream.
  *
- * Returns pointer to an img struct or NULL for error (check img_error()
- * for details)
+ * stream is a FILE* open on the stream (can be NULL which will give error
+ * IMG_FILENOTFOUND so you don't need to handle that case specially).  The
+ * stream should be opened for reading in binary mode and positioned at the
+ * start of the survey data file.
+ *
+ * close_func is a function to call to close the stream (most commonly
+ * fclose, or pclose if the stream was opened using popen()) or NULL if
+ * the caller wants to take care of closing the stream.
+ *
+ * filename is used to determine the format based on the file extension,
+ * and also the leafname with the extension removed is used for the survey
+ * title for formats which don't support a title or when no title is
+ * specified.  If you're not interested in default titles, you can just
+ * pass the extension including a leading "." - e.g. ".3d".  May not be
+ * NULL.
+ *
+ * Returns pointer to an img struct or NULL on error.  Any close function
+ * specified is called on error (unless stream is NULL).
+ */
+#define img_read_stream(S, C, F) img_read_stream_survey((S), (C), (F), NULL)
+
+/* Read processed survey data from an existing stream.
+ *
+ * stream is a FILE* open on the stream (can be NULL which will give error
+ * IMG_FILENOTFOUND so you don't need to handle that case specially).  The
+ * stream should be opened for reading in binary mode and positioned at the
+ * start of the survey data file.
+ *
+ * close_func is a function to call to close the stream (most commonly
+ * fclose, or pclose if the stream was opened using popen()) or NULL if
+ * the caller wants to take care of closing the stream.
+ *
+ * filename is used to determine the format based on the file extension,
+ * and also the leafname with the extension removed is used for the survey
+ * title for formats which don't support a title or when no title is
+ * specified.  If you're not interested in default titles, you can just
+ * pass the extension including a leading "." - e.g. ".3d".  filename must
+ * not be NULL.
+ *
+ * survey points to a survey name to restrict reading to (or NULL for all
+ * survey data in the file)
+ *
+ * Returns pointer to an img struct or NULL on error.  Any close function
+ * specified is called on error.
+ */
+img *img_read_stream_survey(FILE *stream, int (*close_func)(FILE*),
+			    const char *filename,
+			    const char *survey);
+
+/* Open a .3d file for output with no specified coordinate system
+ *
+ * This is a very thin wrapper around img_open_write_cs() which passes NULL for
+ * cs, provided for compatibility with the API provided before support for
+ * coordinate systems was added.
+ *
+ * See img_open_write_cs() for documentation.
  */
 #define img_open_write(F, T, S) img_open_write_cs(F, T, NULL, S)
 
 /* Open a .3d file for output in a specified coordinate system
+ *
  * fnm is the filename
+ *
  * title is the title
- * cs is a PROJ4 string describing the coordinate system (or NULL)
+ *
+ * cs is a PROJ4 string describing the coordinate system (or NULL to not
+ * specify a coordinate system).
+ *
  * flags contains a bitwise-or of any file-wide flags - currently only one
  * is available: img_FFLAG_EXTENDED.
  *
@@ -228,46 +302,90 @@ img *img_open_survey(const char *fnm, const char *survey);
 img *img_open_write_cs(const char *fnm, const char *title, const char * cs,
 		       int flags);
 
-/* Read an item from a .3d file
+/* Write a .3d file to a stream
+ *
+ * stream is a FILE* open on the stream (can be NULL which will give error
+ * IMG_FILENOTFOUND so you don't need to handle that case specially).  The
+ * stream should be opened for writing in binary mode.
+ *
+ * close_func is a function to call to close the stream (most commonly
+ * fclose, or pclose if the stream was opened using popen()) or NULL if
+ * the caller wants to take care of closing the stream.
+ *
+ * title is the title
+ *
+ * cs is a PROJ4 string describing the coordinate system (or NULL to not
+ * specify a coordinate system).
+ *
+ * flags contains a bitwise-or of any file-wide flags - currently only one
+ * is available: img_FFLAG_EXTENDED.
+ *
+ * Returns pointer to an img struct or NULL for error (check img_error()
+ * for details).  Any close function specified is called on error (unless
+ * stream is NULL).
+ */
+img *img_write_stream(FILE *stream, int (*close_func)(FILE*),
+		      const char *title, const char * cs, int flags);
+
+/* Read an item from a processed survey data file
+ *
  * pimg is a pointer to an img struct returned by img_open()
+ *
  * coordinates are returned in p
+ *
  * flags and label name are returned in fields in pimg
+ *
  * Returns img_XXXX as #define-d above
  */
 int img_read_item(img *pimg, img_point *p);
 
 /* Write a item to a .3d file
+ *
  * pimg is a pointer to an img struct returned by img_open_write()
+ *
  * code is one of the img_XXXX #define-d above
+ *
  * flags is the leg, station, or xsect flags
  * (meaningful for img_LINE, img_LABEL, and img_XSECT respectively)
+ *
  * s is the label (only meaningful for img_LABEL)
+ *
  * x, y, z are the coordinates
  */
 void img_write_item(img *pimg, int code, int flags, const char *s,
 		    double x, double y, double z);
 
 /* Write error information for the current traverse
+ *
  * n_legs is the number of legs in the traverse
+ *
  * length is the traverse length (in m)
+ *
  * E is the ratio of the observed misclosure to the theoretical one
+ *
  * H is the ratio of the observed horizontal misclosure to the theoretical one
+ *
  * V is the ratio of the observed vertical misclosure to the theoretical one
  */
 void img_write_errors(img *pimg, int n_legs, double length,
 		      double E, double H, double V);
 
-/* rewind a .3d file opened for reading so the data can be read in
- * several passes
+/* rewind a processed survey data file opened for reading
+ *
+ * This is useful if you want to read the data in several passes.
+ *
  * pimg is a pointer to an img struct returned by img_open()
+ *
  * Returns: non-zero for success, zero for error (check img_error() for
  *   details)
  */
 int img_rewind(img *pimg);
 
-/* Close a .3d file
+/* Close a processed survey data file
+ *
  * pimg is a pointer to an img struct returned by img_open() or
  *   img_open_write()
+ *
  * Returns: non-zero for success, zero for error (check img_error() for
  *   details)
  */
@@ -281,6 +399,7 @@ typedef enum {
 } img_errcode;
 
 /* Read the error code
+ *
  * If img_open(), img_open_survey() or img_open_write() returns NULL, or
  * img_rewind() or img_close() returns 0, or img_read_item() returns img_BAD
  * then you can call this function to discover why.
