@@ -28,25 +28,25 @@
 extern void
 useful_put16(int16_t w, FILE *fh)
 {
-   putc((char)(w), fh);
-   putc((char)(w >> 8l), fh);
+   PUTC((char)(w), fh);
+   PUTC((char)(w >> 8l), fh);
 }
 
 extern void
 useful_put32(int32_t w, FILE *fh)
 {
-   putc((char)(w), fh);
-   putc((char)(w >> 8l), fh);
-   putc((char)(w >> 16l), fh);
-   putc((char)(w >> 24l), fh);
+   PUTC((char)(w), fh);
+   PUTC((char)(w >> 8l), fh);
+   PUTC((char)(w >> 16l), fh);
+   PUTC((char)(w >> 24l), fh);
 }
 
 extern int16_t
 useful_get16(FILE *fh)
 {
    int16_t w;
-   w = getc(fh);
-   w |= (int16_t)(getc(fh) << 8l);
+   w = GETC(fh);
+   w |= (int16_t)(GETC(fh) << 8l);
    return w;
 }
 
@@ -54,10 +54,10 @@ extern int32_t
 useful_get32(FILE *fh)
 {
    int32_t w;
-   w = getc(fh);
-   w |= (int32_t)(getc(fh) << 8l);
-   w |= (int32_t)(getc(fh) << 16l);
-   w |= (int32_t)(getc(fh) << 24l);
+   w = GETC(fh);
+   w |= (int32_t)(GETC(fh) << 8l);
+   w |= (int32_t)(GETC(fh) << 16l);
+   w |= (int32_t)(GETC(fh) << 24l);
    return w;
 }
 #endif
