@@ -31,6 +31,9 @@
 # include <config.h>
 #endif
 
+#include "message.h"
+#define _
+
 #if !defined __STDC__ || !__STDC__
 /* This is a separate conditional since some stdc systems
    reject `defined (const)'.  */
@@ -81,10 +84,10 @@
 # if (HAVE_LIBINTL_H && ENABLE_NLS) || defined _LIBC
 #  include <libintl.h>
 #  ifndef _
-#include "message.h"
+#   define _(msgid)	gettext (msgid)
 #  endif
 # else
-#include "message.h"
+#  define _(msgid)	(msgid)
 # endif
 # if defined _LIBC && defined USE_IN_LIBIO
 #  include <wchar.h>
@@ -694,7 +697,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 	      char *buf;
 
-	      if (__asprintf (&buf, msg(/*%s: option “%s” is ambiguous\n*/300),
+	      if (__asprintf (&buf, _("%s: option `%s' is ambiguous\n"),
 			      argv[0], argv[optind]) >= 0)
 		{
 
@@ -739,7 +742,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			{
 			  /* --option */
 #if defined _LIBC && defined USE_IN_LIBIO
-			  n = __asprintf (&buf, msg(/*%s: option “--%s” doesn’t allow an argument\n*/303),
+			  n = __asprintf (&buf, _("\
+%s: option `--%s' doesn't allow an argument\n"),
 					  argv[0], pfound->name);
 #else
 			  fprintf (stderr, msg(/*%s: option “--%s” doesn’t allow an argument\n*/303),
@@ -750,7 +754,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			{
 			  /* +option or -option */
 #if defined _LIBC && defined USE_IN_LIBIO
-			  n = __asprintf (&buf, msg(/*%s: option “%c%s” doesn’t allow an argument\n*/302),
+			  n = __asprintf (&buf, _("\
+%s: option `%c%s' doesn't allow an argument\n"),
 					  argv[0], argv[optind - 1][0],
 					  pfound->name);
 #else
@@ -789,7 +794,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		      char *buf;
 
-		      if (__asprintf (&buf, msg(/*%s: option “%s” requires an argument\n*/305),
+		      if (__asprintf (&buf, _("\
+%s: option `%s' requires an argument\n"),
 				      argv[0], argv[optind - 1]) >= 0)
 			{
 			  if (_IO_fwide (stderr, 0) > 0)
@@ -839,7 +845,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		{
 		  /* --option */
 #if defined _LIBC && defined USE_IN_LIBIO
-		  n = __asprintf (&buf, msg(/*%s: unrecognized option “--%s”\n*/307),
+		  n = __asprintf (&buf, _("%s: unrecognized option `--%s'\n"),
 				  argv[0], nextchar);
 #else
 		  fprintf (stderr, msg(/*%s: unrecognized option “--%s”\n*/307),
@@ -850,7 +856,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		{
 		  /* +option or -option */
 #if defined _LIBC && defined USE_IN_LIBIO
-		  n = __asprintf (&buf, msg(/*%s: unrecognized option “%c%s”\n*/308),
+		  n = __asprintf (&buf, _("%s: unrecognized option `%c%s'\n"),
 				  argv[0], argv[optind][0], nextchar);
 #else
 		  fprintf (stderr, msg(/*%s: unrecognized option “%c%s”\n*/308),
@@ -896,20 +902,22 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	      int n;
 #endif
 
+#if 0
 	    if (posixly_correct)
 	      {
 		/* 1003.2 specifies the format of this message.  */
 #if defined _LIBC && defined USE_IN_LIBIO
-		n = __asprintf (&buf, msg(/*%s: illegal option -- %c\n*/309),
+		n = __asprintf (&buf, _("%s: illegal option -- %c\n"),
 				argv[0], c);
 #else
-		fprintf (stderr, msg(/*%s: illegal option -- %c\n*/309), argv[0], c);
+		fprintf (stderr, _("%s: illegal option -- %c\n"), argv[0], c);
 #endif
 	      }
 	    else
+#endif
 	      {
 #if defined _LIBC && defined USE_IN_LIBIO
-		n = __asprintf (&buf, msg(/*%s: invalid option -- %c\n*/310),
+		n = __asprintf (&buf, _("%s: invalid option -- %c\n"),
 				argv[0], c);
 #else
 		fprintf (stderr, msg(/*%s: invalid option -- %c\n*/310), argv[0], c);
@@ -931,6 +939,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	optopt = c;
 	return '?';
       }
+#if 0
     /* Convenience. Treat POSIX -W foo same as long option --foo */
     if (temp[0] == 'W' && temp[1] == ';')
       {
@@ -959,7 +968,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		char *buf;
 
 		if (__asprintf (&buf,
-				msg(/*%s: option requires an argument -- %c\n*/306),
+				_("%s: option requires an argument -- %c\n"),
 				argv[0], c) >= 0)
 		  {
 		    if (_IO_fwide (stderr, 0) > 0)
@@ -970,7 +979,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		    free (buf);
 		  }
 #else
-		fprintf (stderr, msg(/*%s: option requires an argument -- %c\n*/306),
+		fprintf (stderr, _("%s: option requires an argument -- %c\n"),
 			 argv[0], c);
 #endif
 	      }
@@ -1022,7 +1031,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		char *buf;
 
-		if (__asprintf (&buf, msg(/*%s: option “-W %s” is ambiguous\n*/301),
+		if (__asprintf (&buf, _("%s: option `-W %s' is ambiguous\n"),
 				argv[0], argv[optind]) >= 0)
 		  {
 		    if (_IO_fwide (stderr, 0) > 0)
@@ -1033,7 +1042,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 		    free (buf);
 		  }
 #else
-		fprintf (stderr, msg(/*%s: option “-W %s” is ambiguous\n*/301),
+		fprintf (stderr, _("%s: option `-W %s' is ambiguous\n"),
 			 argv[0], argv[optind]);
 #endif
 	      }
@@ -1057,7 +1066,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 			char *buf;
 
-			if (__asprintf (&buf, msg(/*%s: option “-W %s” doesn’t allow an argument\n*/304),
+			if (__asprintf (&buf, _("\
+%s: option `-W %s' doesn't allow an argument\n"),
 					argv[0], pfound->name) >= 0)
 			  {
 			    if (_IO_fwide (stderr, 0) > 0)
@@ -1068,7 +1078,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			    free (buf);
 			  }
 #else
-			fprintf (stderr, msg(/*%s: option “-W %s” doesn’t allow an argument\n*/304),
+			fprintf (stderr, _("\
+%s: option `-W %s' doesn't allow an argument\n"),
 				 argv[0], pfound->name);
 #endif
 		      }
@@ -1088,7 +1099,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 			char *buf;
 
-			if (__asprintf (&buf, msg(/*%s: option “%s” requires an argument\n*/305),
+			if (__asprintf (&buf, _("\
+%s: option `%s' requires an argument\n"),
 					argv[0], argv[optind - 1]) >= 0)
 			  {
 			    if (_IO_fwide (stderr, 0) > 0)
@@ -1100,7 +1112,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 			  }
 #else
 			fprintf (stderr,
-				 msg(/*%s: option “%s” requires an argument\n*/305),
+				 _("%s: option `%s' requires an argument\n"),
 				 argv[0], argv[optind - 1]);
 #endif
 		      }
@@ -1121,6 +1133,7 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 	  nextchar = NULL;
 	  return 'W';	/* Let the application handle it.   */
       }
+#endif
     if (temp[1] == ':')
       {
 	if (temp[2] == ':')
@@ -1153,7 +1166,8 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
 #if defined _LIBC && defined USE_IN_LIBIO
 		    char *buf;
 
-		    if (__asprintf (&buf, msg(/*%s: option requires an argument -- %c\n*/306),
+		    if (__asprintf (&buf, _("\
+%s: option requires an argument -- %c\n"),
 				    argv[0], c) >= 0)
 		      {
 			if (_IO_fwide (stderr, 0) > 0)
